@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::ClassStartup;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-09-09'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::ClassStartup - Benchmark startup of classes using
 
 =head1 VERSION
 
-This document describes version 0.08 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-26.
+This document describes version 0.09 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
 
 =head1 SYNOPSIS
 
@@ -49,67 +49,51 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.06
+L<Perl::Examples::Accessors::Array> 0.08
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.06
+L<Perl::Examples::Accessors::ClassAccessor> 0.08
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.06
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.08
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.06
+L<Perl::Examples::Accessors::ClassInsideOut> 0.08
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.06
+L<Perl::Examples::Accessors::ClassTiny> 0.08
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.06
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.08
 
-L<Perl::Examples::Accessors::Hash> 0.06
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.08
 
-L<Perl::Examples::Accessors::Mo> 0.06
+L<Perl::Examples::Accessors::Hash> 0.08
 
-L<Perl::Examples::Accessors::MojoBase> 0.06
+L<Perl::Examples::Accessors::Mo> 0.08
 
-L<Perl::Examples::Accessors::Moo> 0.06
+L<Perl::Examples::Accessors::MojoBase> 0.08
 
-L<Perl::Examples::Accessors::Moose> 0.06
+L<Perl::Examples::Accessors::Moo> 0.08
 
-L<Perl::Examples::Accessors::Mouse> 0.06
+L<Perl::Examples::Accessors::Moose> 0.08
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.06
+L<Perl::Examples::Accessors::Mouse> 0.08
 
-L<Perl::Examples::Accessors::Scalar> 0.06
+L<Perl::Examples::Accessors::ObjectSimple> 0.08
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.06
+L<Perl::Examples::Accessors::Scalar> 0.08
+
+L<Perl::Examples::Accessors::SimpleAccessor> 0.08
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Perl::Examples::Accessors::Mo (perl_code)
+=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
 
-L<Perl::Examples::Accessors::Mo>
+L<Perl::Examples::Accessors::ObjectSimple>
 
 
 
-=item * Perl::Examples::Accessors::Scalar (perl_code)
+=item * Perl::Examples::Accessors::Moo (perl_code)
 
-L<Perl::Examples::Accessors::Scalar>
-
-
-
-=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
-
-L<Perl::Examples::Accessors::ClassXSAccessor>
-
-
-
-=item * Perl::Examples::Accessors::ClassInsideOut (perl_code)
-
-L<Perl::Examples::Accessors::ClassInsideOut>
-
-
-
-=item * Perl::Examples::Accessors::SimpleAccessor (perl_code)
-
-L<Perl::Examples::Accessors::SimpleAccessor>
+L<Perl::Examples::Accessors::Moo>
 
 
 
@@ -119,27 +103,9 @@ L<Perl::Examples::Accessors::Mouse>
 
 
 
-=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
+=item * Perl::Examples::Accessors::Mo (perl_code)
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray>
-
-
-
-=item * Perl::Examples::Accessors::Moose (perl_code)
-
-L<Perl::Examples::Accessors::Moose>
-
-
-
-=item * Perl::Examples::Accessors::Hash (perl_code)
-
-L<Perl::Examples::Accessors::Hash>
-
-
-
-=item * Perl::Examples::Accessors::ClassAccessor (perl_code)
-
-L<Perl::Examples::Accessors::ClassAccessor>
+L<Perl::Examples::Accessors::Mo>
 
 
 
@@ -155,9 +121,33 @@ L<Perl::Examples::Accessors::ClassAccessorArray>
 
 
 
-=item * Perl::Examples::Accessors::Moo (perl_code)
+=item * Perl::Examples::Accessors::Moose (perl_code)
 
-L<Perl::Examples::Accessors::Moo>
+L<Perl::Examples::Accessors::Moose>
+
+
+
+=item * Perl::Examples::Accessors::ClassTiny (perl_code)
+
+L<Perl::Examples::Accessors::ClassTiny>
+
+
+
+=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessor>
+
+
+
+=item * Perl::Examples::Accessors::Hash (perl_code)
+
+L<Perl::Examples::Accessors::Hash>
+
+
+
+=item * Perl::Examples::Accessors::SimpleAccessor (perl_code)
+
+L<Perl::Examples::Accessors::SimpleAccessor>
 
 
 
@@ -167,9 +157,27 @@ L<Perl::Examples::Accessors::Array>
 
 
 
-=item * Perl::Examples::Accessors::ObjectSimple (perl_code)
+=item * Perl::Examples::Accessors::Scalar (perl_code)
 
-L<Perl::Examples::Accessors::ObjectSimple>
+L<Perl::Examples::Accessors::Scalar>
+
+
+
+=item * Perl::Examples::Accessors::ClassAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassAccessor>
+
+
+
+=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessorArray>
+
+
+
+=item * Perl::Examples::Accessors::ClassInsideOut (perl_code)
+
+L<Perl::Examples::Accessors::ClassInsideOut>
 
 
 
@@ -177,30 +185,32 @@ L<Perl::Examples::Accessors::ObjectSimple>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::ClassStartup >>):
 
- +-------------------------------------------------+-----------+------------------------+------------+----------+---------+
- | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors  | samples |
- +-------------------------------------------------+-----------+------------------------+------------+----------+---------+
- | Perl::Examples::Accessors::Moose                |     120   |                  117.5 |        1   |   0.0004 |      20 |
- | Perl::Examples::Accessors::Moo                  |      21   |                   18.5 |        5.8 | 3.2e-05  |      22 |
- | Perl::Examples::Accessors::Mouse                |      17   |                   14.5 |        7   | 4.2e-05  |      20 |
- | Perl::Examples::Accessors::MojoBase             |      11   |                    8.5 |       11   | 2.8e-05  |      20 |
- | Perl::Examples::Accessors::ClassInsideOut       |      11   |                    8.5 |       11   | 4.8e-05  |      20 |
- | Perl::Examples::Accessors::ClassXSAccessorArray |       8.2 |                    5.7 |       15   | 6.6e-05  |      20 |
- | Perl::Examples::Accessors::ClassAccessor        |       8.1 |                    5.6 |       15   |   5e-05  |      20 |
- | Perl::Examples::Accessors::ObjectSimple         |       8.1 |                    5.6 |       15   | 4.6e-05  |      20 |
- | Perl::Examples::Accessors::ClassXSAccessor      |       7.8 |                    5.3 |       16   | 4.2e-05  |      20 |
- | Perl::Examples::Accessors::SimpleAccessor       |       4.9 |                    2.4 |       25   | 3.7e-05  |      20 |
- | Perl::Examples::Accessors::Mo                   |       4.4 |                    1.9 |       28   | 2.4e-05  |      22 |
- | Perl::Examples::Accessors::ClassAccessorArray   |       4.3 |                    1.8 |       28   | 2.2e-05  |      20 |
- | Perl::Examples::Accessors::Scalar               |       2.9 |                    0.4 |       42   | 2.7e-05  |      20 |
- | Perl::Examples::Accessors::Hash                 |       2.8 |                    0.3 |       43   | 1.8e-05  |      20 |
- | Perl::Examples::Accessors::Array                |       2.8 |                    0.3 |       44   | 1.6e-05  |      20 |
- | perl -e1 (baseline)                             |       2.5 |                    0   |       49   | 5.5e-06  |      20 |
- +-------------------------------------------------+-----------+------------------------+------------+----------+---------+
+ #table1#
+ +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
+ | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
+ | Perl::Examples::Accessors::Moose                |     170   |    165.9               |        1   |   0.00081 |      20 |
+ | Perl::Examples::Accessors::Moo                  |      31   |     26.9               |        5.5 | 9.9e-05   |      20 |
+ | Perl::Examples::Accessors::Mouse                |      26   |     21.9               |        6.7 | 3.5e-05   |      20 |
+ | Perl::Examples::Accessors::MojoBase             |      17   |     12.9               |       10   |   0.00015 |      20 |
+ | Perl::Examples::Accessors::ClassInsideOut       |      16   |     11.9               |       11   |   5e-05   |      20 |
+ | Perl::Examples::Accessors::ClassTiny            |      14   |      9.9               |       12   | 3.5e-05   |      20 |
+ | Perl::Examples::Accessors::ObjectSimple         |      13   |      8.9               |       13   |   0.0001  |      20 |
+ | Perl::Examples::Accessors::ClassXSAccessorArray |      12   |      7.9               |       14   | 5.7e-05   |      20 |
+ | Perl::Examples::Accessors::ClassXSAccessor      |      12   |      7.9               |       15   | 2.2e-05   |      20 |
+ | Perl::Examples::Accessors::ClassAccessor        |      12   |      7.9               |       15   | 5.8e-05   |      20 |
+ | Perl::Examples::Accessors::SimpleAccessor       |       7.5 |      3.4               |       23   | 1.7e-05   |      20 |
+ | Perl::Examples::Accessors::ClassAccessorArray   |       6.9 |      2.8               |       25   | 2.3e-05   |      20 |
+ | Perl::Examples::Accessors::Mo                   |       6.7 |      2.6               |       26   | 2.1e-05   |      20 |
+ | Perl::Examples::Accessors::Scalar               |       5.5 |      1.4               |       31   | 3.6e-05   |      20 |
+ | Perl::Examples::Accessors::Array                |       5   |      0.9               |       35   | 1.9e-05   |      20 |
+ | Perl::Examples::Accessors::Hash                 |       4.9 |      0.800000000000001 |       35   | 8.5e-06   |      20 |
+ | perl -e1 (baseline)                             |       4.1 |      0                 |       42   | 1.5e-05   |      20 |
+ +-------------------------------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
 
