@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-09-09'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -40,7 +40,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.08 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-26.
+This document describes version 0.09 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
 
 =head1 SYNOPSIS
 
@@ -58,79 +58,57 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors> 0.06
+L<Perl::Examples::Accessors> 0.08
 
-L<Perl::Examples::Accessors::Array> 0.06
+L<Perl::Examples::Accessors::Array> 0.08
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.06
+L<Perl::Examples::Accessors::ClassAccessor> 0.08
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.06
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.08
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.06
+L<Perl::Examples::Accessors::ClassInsideOut> 0.08
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.06
+L<Perl::Examples::Accessors::ClassTiny> 0.08
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.06
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.08
 
-L<Perl::Examples::Accessors::Hash> 0.06
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.08
 
-L<Perl::Examples::Accessors::Mo> 0.06
+L<Perl::Examples::Accessors::Hash> 0.08
 
-L<Perl::Examples::Accessors::MojoBase> 0.06
+L<Perl::Examples::Accessors::Mo> 0.08
 
-L<Perl::Examples::Accessors::Moo> 0.06
+L<Perl::Examples::Accessors::MojoBase> 0.08
 
-L<Perl::Examples::Accessors::Moose> 0.06
+L<Perl::Examples::Accessors::Moo> 0.08
 
-L<Perl::Examples::Accessors::Mouse> 0.06
+L<Perl::Examples::Accessors::Moose> 0.08
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.06
+L<Perl::Examples::Accessors::Mouse> 0.08
 
-L<Perl::Examples::Accessors::Scalar> 0.06
+L<Perl::Examples::Accessors::ObjectSimple> 0.08
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.06
+L<Perl::Examples::Accessors::Scalar> 0.08
+
+L<Perl::Examples::Accessors::SimpleAccessor> 0.08
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Mo (perl_code)
+=item * Object::Simple (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Mo->new
+ Perl::Examples::Accessors::ObjectSimple->new
 
 
 
-=item * no generator (scalar-based) (perl_code)
+=item * Moo (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Scalar->new
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessor->new
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassInsideOut->new
-
-
-
-=item * Simple::Accessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::SimpleAccessor->new
+ Perl::Examples::Accessors::Moo->new
 
 
 
@@ -142,35 +120,11 @@ Code template:
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Mo (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ClassXSAccessorArray->new
-
-
-
-=item * Moose (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moose->new
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Hash->new
-
-
-
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessor->new
+ Perl::Examples::Accessors::Mo->new
 
 
 
@@ -190,11 +144,43 @@ Code template:
 
 
 
-=item * Moo (perl_code)
+=item * Moose (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Moo->new
+ Perl::Examples::Accessors::Moose->new
+
+
+
+=item * Class::Tiny (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassTiny->new
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessor->new
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Hash->new
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::SimpleAccessor->new
 
 
 
@@ -206,11 +192,35 @@ Code template:
 
 
 
-=item * Object::Simple (perl_code)
+=item * no generator (scalar-based) (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::ObjectSimple->new
+ Perl::Examples::Accessors::Scalar->new
+
+
+
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessor->new
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessorArray->new
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassInsideOut->new
 
 
 
@@ -218,29 +228,31 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Construction >>):
 
- +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
- | participant                 | rate (/s) | time (μs) | vs_slowest | result_size (b) |  errors | samples |
- +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
- | Class::InsideOut            |    396000 |  2.52     |    1       |             144 | 2.5e-09 |      20 |
- | Simple::Accessor            |    582633 |  1.71635  |    1.47078 |             120 |   0     |      23 |
- | Moose                       |    940000 |  1.1      |    2.4     |             120 | 1.7e-09 |      20 |
- | Mo                          |   1252940 |  0.798125 |    3.16287 |             120 |   0     |      25 |
- | Moo                         |   1638420 |  0.610344 |    4.13597 |             120 |   0     |      21 |
- | Mouse                       |   1700000 |  0.59     |    4.3     |             120 | 6.2e-10 |      20 |
- | Class::Accessor             |   1780000 |  0.561    |    4.5     |             120 | 2.2e-10 |      20 |
- | no generator (array-based)  |   2470000 |  0.405    |    6.24    |              64 | 1.9e-10 |      27 |
- | Mojo::Base                  |   2937600 |  0.340414 |    7.41558 |             120 |   0     |      20 |
- | no generator (hash-based)   |   2960000 |  0.338    |    7.46    |             120 | 4.7e-11 |      20 |
- | Object::Simple              |   3000000 |  0.33     |    7.5     |             120 | 8.3e-10 |      20 |
- | no generator (scalar-based) |   3200000 |  0.313    |    8.07    |              72 |   1e-10 |      20 |
- | Class::Accessor::Array      |   3230000 |  0.31     |    8.15    |              64 | 8.5e-11 |      30 |
- | Class::XSAccessor           |   5100000 |  0.19     |   13       |             120 | 3.2e-10 |      20 |
- | Class::XSAccessor::Array    |   5305300 |  0.188491 |   13.3925  |              64 |   0     |      20 |
- +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ #table1#
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | participant                 | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
+ | Class::InsideOut            |    190000 |     5.2   |       1    | 6.7e-09 |      20 |
+ | Simple::Accessor            |    330000 |     3     |       1.7  | 6.5e-09 |      21 |
+ | Class::Tiny                 |    380000 |     2.6   |       2    | 3.3e-09 |      20 |
+ | Moose                       |    520000 |     1.9   |       2.7  | 3.3e-09 |      20 |
+ | Mo                          |    800000 |     1.3   |       4.2  | 1.8e-09 |      26 |
+ | Moo                         |   1050000 |     0.949 |       5.52 | 1.4e-10 |      20 |
+ | Class::Accessor             |   1100000 |     0.91  |       5.7  | 1.1e-09 |      25 |
+ | Mouse                       |   1400000 |     0.7   |       7.5  | 1.8e-09 |      26 |
+ | no generator (array-based)  |   1740000 |     0.576 |       9.1  | 2.1e-10 |      21 |
+ | Object::Simple              |   2200000 |     0.46  |      11    | 7.5e-10 |      25 |
+ | Mojo::Base                  |   2200000 |     0.45  |      12    | 8.4e-10 |      20 |
+ | no generator (hash-based)   |   2230000 |     0.448 |      11.7  | 9.3e-11 |      20 |
+ | Class::Accessor::Array      |   2470000 |     0.404 |      13    | 9.3e-11 |      20 |
+ | no generator (scalar-based) |   2480000 |     0.403 |      13    | 9.3e-11 |      21 |
+ | Class::XSAccessor           |   3540000 |     0.282 |      18.6  | 1.3e-10 |      24 |
+ | Class::XSAccessor::Array    |   3600000 |     0.28  |      19    |   1e-09 |      29 |
+ +-----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
