@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-09-09'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.08 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-26.
+This document describes version 0.09 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
 
 =head1 SYNOPSIS
 
@@ -55,21 +55,23 @@ L<Class::Accessor::Array> 0.02
 
 L<Class::InsideOut> 1.13
 
+L<Class::Tiny> 1.004
+
 L<Class::XSAccessor> 1.19
 
 L<Class::XSAccessor::Array> 1.19
 
-L<Mo> 0.39
+L<Mo> 0.40
 
 L<Mojo::Base>
 
-L<Moo> 2.001001
+L<Moo> 2.002004
 
-L<Moose> 2.1605
+L<Moose> 2.1805
 
 L<Mouse> v2.4.5
 
-L<Object::Simple> 3.16
+L<Object::Simple> 3.1703
 
 L<Simple::Accessor> 1.02
 
@@ -77,31 +79,15 @@ L<Simple::Accessor> 1.02
 
 =over
 
-=item * Mo (perl_code)
+=item * Object::Simple (perl_code)
 
-L<Mo>
+L<Object::Simple>
 
 
 
-=item *  (perl_code)
+=item * Moo (perl_code)
 
-
-
-=item * Class::XSAccessor (perl_code)
-
-L<Class::XSAccessor>
-
-
-
-=item * Class::InsideOut (perl_code)
-
-L<Class::InsideOut>
-
-
-
-=item * Simple::Accessor (perl_code)
-
-L<Simple::Accessor>
+L<Moo>
 
 
 
@@ -111,25 +97,9 @@ L<Mouse>
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Mo (perl_code)
 
-L<Class::XSAccessor::Array>
-
-
-
-=item * Moose (perl_code)
-
-L<Moose>
-
-
-
-=item *  (perl_code)
-
-
-
-=item * Class::Accessor (perl_code)
-
-L<Class::Accessor>
+L<Mo>
 
 
 
@@ -145,9 +115,21 @@ L<Class::Accessor::Array>
 
 
 
-=item * Moo (perl_code)
+=item * Moose (perl_code)
 
-L<Moo>
+L<Moose>
+
+
+
+=item * Class::Tiny (perl_code)
+
+L<Class::Tiny>
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+L<Class::XSAccessor>
 
 
 
@@ -155,9 +137,35 @@ L<Moo>
 
 
 
-=item * Object::Simple (perl_code)
+=item * Simple::Accessor (perl_code)
 
-L<Object::Simple>
+L<Simple::Accessor>
+
+
+
+=item *  (perl_code)
+
+
+
+=item *  (perl_code)
+
+
+
+=item * Class::Accessor (perl_code)
+
+L<Class::Accessor>
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+L<Class::XSAccessor::Array>
+
+
+
+=item * Class::InsideOut (perl_code)
+
+L<Class::InsideOut>
 
 
 
@@ -165,26 +173,28 @@ L<Object::Simple>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
 
+ #table1#
  +--------------------------+-----------+------------------------+------------+-----------+---------+
  | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
  +--------------------------+-----------+------------------------+------------+-----------+---------+
- | Moose                    |     120   |                  117.4 |        1   |   0.00029 |      20 |
- | Mouse                    |      18   |                   15.4 |        6.8 | 5.7e-05   |      20 |
- | Moo                      |      14   |                   11.4 |        8.9 | 6.4e-05   |      20 |
- | Class::InsideOut         |      11   |                    8.4 |       11   | 7.6e-05   |      20 |
- | Mojo::Base               |      10   |                    7.4 |       11   | 5.2e-05   |      21 |
- | Class::XSAccessor::Array |       8.2 |                    5.6 |       15   | 5.9e-05   |      20 |
- | Object::Simple           |       8.2 |                    5.6 |       15   | 4.2e-05   |      20 |
- | Class::Accessor          |       7.7 |                    5.1 |       16   | 6.3e-05   |      20 |
- | Class::XSAccessor        |       7.7 |                    5.1 |       16   | 4.2e-05   |      20 |
- | Simple::Accessor         |       5   |                    2.4 |       30   | 5.2e-05   |      20 |
- | Class::Accessor::Array   |       4.3 |                    1.7 |       28   | 3.6e-05   |      20 |
- | Mo                       |       4.2 |                    1.6 |       28   | 4.2e-05   |      23 |
- | perl -e1 (baseline)      |       2.6 |                    0   |       47   | 7.2e-06   |      20 |
+ | Moose                    |     200   |                  195.3 |        1   |   0.0032  |      20 |
+ | Mouse                    |      26   |                   21.3 |        6.8 |   0.00013 |      22 |
+ | Moo                      |      20   |                   15.3 |        9.1 |   0.00015 |      20 |
+ | Mojo::Base               |      16   |                   11.3 |       11   | 9.5e-05   |      20 |
+ | Class::InsideOut         |      16   |                   11.3 |       11   |   3e-05   |      20 |
+ | Class::Tiny              |      14   |                    9.3 |       13   |   5e-05   |      20 |
+ | Class::XSAccessor        |      10   |                    5.3 |       10   |   0.00025 |      20 |
+ | Object::Simple           |      12   |                    7.3 |       15   | 4.2e-05   |      20 |
+ | Class::XSAccessor::Array |      12   |                    7.3 |       15   | 7.2e-05   |      20 |
+ | Class::Accessor          |      12   |                    7.3 |       15   | 7.5e-05   |      20 |
+ | Mo                       |       7.5 |                    2.8 |       24   | 4.7e-05   |      21 |
+ | Simple::Accessor         |       7.2 |                    2.5 |       25   | 2.1e-05   |      20 |
+ | Class::Accessor::Array   |       6.9 |                    2.2 |       26   | 6.4e-05   |      20 |
+ | perl -e1 (baseline)      |       4.7 |                    0   |       38   | 3.6e-05   |      20 |
  +--------------------------+-----------+------------------------+------------+-----------+---------+
 
 =head1 DESCRIPTION
