@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Get;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-09-09'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -50,7 +50,7 @@ Bencher::Scenario::Accessors::Get - Benchmark attribute read/get
 
 =head1 VERSION
 
-This document describes version 0.08 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-26.
+This document describes version 0.09 of Bencher::Scenario::Accessors::Get (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
 
 =head1 SYNOPSIS
 
@@ -68,67 +68,53 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.06
+L<Perl::Examples::Accessors::Array> 0.08
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.06
+L<Perl::Examples::Accessors::ClassAccessor> 0.08
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.06
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.08
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.06
+L<Perl::Examples::Accessors::ClassInsideOut> 0.08
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.06
+L<Perl::Examples::Accessors::ClassTiny> 0.08
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.06
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.08
 
-L<Perl::Examples::Accessors::Hash> 0.06
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.08
 
-L<Perl::Examples::Accessors::Mo> 0.06
+L<Perl::Examples::Accessors::Hash> 0.08
 
-L<Perl::Examples::Accessors::MojoBase> 0.06
+L<Perl::Examples::Accessors::Mo> 0.08
 
-L<Perl::Examples::Accessors::Moo> 0.06
+L<Perl::Examples::Accessors::MojoBase> 0.08
 
-L<Perl::Examples::Accessors::Moose> 0.06
+L<Perl::Examples::Accessors::Moo> 0.08
 
-L<Perl::Examples::Accessors::Mouse> 0.06
+L<Perl::Examples::Accessors::Moose> 0.08
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.06
+L<Perl::Examples::Accessors::Mouse> 0.08
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.06
+L<Perl::Examples::Accessors::ObjectSimple> 0.08
+
+L<Perl::Examples::Accessors::SimpleAccessor> 0.08
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Mo (perl_code)
+=item * Object::Simple (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
 
 
 
-=item * Class::XSAccessor (perl_code)
+=item * Moo (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Simple::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -140,35 +126,11 @@ Code template:
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Mo (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Moose (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
-
-
-
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -188,11 +150,43 @@ Code template:
 
 
 
-=item * Moo (perl_code)
+=item * Moose (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::Tiny (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -204,11 +198,27 @@ Code template:
 
 
 
-=item * Object::Simple (perl_code)
+=item * Class::Accessor (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o->attr1(42); $o }; $o->attr1
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o->attr1(42); $o }; $o->attr1
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o->attr1(42); $o }; $o->attr1
 
 
 
@@ -232,29 +242,31 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Get >>):
 
+ #table1#
  +----------------------------+-----------+-----------+------------+---------+---------+
  | participant                | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Class::Accessor            |   2320000 |     431   |       1    |   2e-10 |      23 |
- | Class::InsideOut           |   3640000 |     275   |       1.57 | 1.4e-10 |      20 |
- | Simple::Accessor           |   3800000 |     270   |       1.6  | 4.9e-10 |      24 |
- | no generator (hash-based)  |   5400000 |     180   |       2.3  | 4.2e-10 |      20 |
- | Mo                         |   5400000 |     180   |       2.3  | 9.4e-10 |      20 |
- | no generator (array-based) |   5500000 |     180   |       2.4  | 4.2e-10 |      20 |
- | Mojo::Base                 |   5600000 |     180   |       2.4  | 3.1e-10 |      20 |
- | Object::Simple             |   6010000 |     166.4 |       2.59 |   1e-11 |      20 |
- | Moose                      |   6810000 |     147   |       2.93 | 4.5e-11 |      22 |
- | Class::Accessor::Array     |   6960000 |     144   |       3    | 4.6e-11 |      20 |
- | Mouse                      |  13200000 |      75.8 |       5.68 | 1.1e-11 |      20 |
- | Class::XSAccessor          |  13300000 |      75.2 |       5.73 | 6.5e-11 |      21 |
- | Moo                        |  14000000 |      71   |       6.1  | 1.6e-10 |      20 |
- | Class::XSAccessor::Array   |  20000000 |      50   |       8.6  | 2.3e-10 |      20 |
- | raw hash access            |  27000000 |      36   |      12    | 1.5e-10 |      20 |
- | raw array access           |  39000000 |      25   |      17    | 2.1e-10 |      20 |
+ | Class::Accessor            |   2000000 |     510   |       1    | 8.5e-10 |      20 |
+ | Class::InsideOut           |   2450000 |     408   |       1.25 | 2.5e-10 |      20 |
+ | Simple::Accessor           |   2670000 |     375   |       1.36 | 9.2e-11 |      20 |
+ | Mojo::Base                 |   4000000 |     250   |       2.1  | 4.2e-10 |      20 |
+ | Mo                         |   4670000 |     214   |       2.38 | 4.6e-11 |      20 |
+ | no generator (hash-based)  |   5200000 |     190   |       2.6  | 7.6e-10 |      24 |
+ | Class::Tiny                |   5500000 |     180   |       2.8  | 5.1e-10 |      21 |
+ | Object::Simple             |   5600000 |     180   |       2.8  | 2.1e-10 |      20 |
+ | Moose                      |   5720000 |     175   |       2.91 | 4.6e-11 |      24 |
+ | Class::Accessor::Array     |   5980000 |     167   |       3.04 | 5.8e-11 |      20 |
+ | no generator (array-based) |   6180000 |     162   |       3.14 | 9.2e-11 |      20 |
+ | Mouse                      |  10200000 |      98.5 |       5.16 | 6.1e-11 |      33 |
+ | Class::XSAccessor          |  14000000 |      71.2 |       7.14 | 4.6e-11 |      20 |
+ | Class::XSAccessor::Array   |  19000000 |      54   |       9.4  | 2.3e-10 |      20 |
+ | Moo                        |  21000000 |      47   |      11    | 2.7e-10 |      20 |
+ | raw hash access            |  23000000 |      44   |      12    | 4.7e-11 |      28 |
+ | raw array access           |  36000000 |      28   |      18    |   7e-11 |      20 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
