@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Set;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-09-09'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -50,7 +50,7 @@ Bencher::Scenario::Accessors::Set - Benchmark attribute write/set
 
 =head1 VERSION
 
-This document describes version 0.08 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-06-26.
+This document describes version 0.09 of Bencher::Scenario::Accessors::Set (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-09-09.
 
 =head1 SYNOPSIS
 
@@ -68,67 +68,53 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.06
+L<Perl::Examples::Accessors::Array> 0.08
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.06
+L<Perl::Examples::Accessors::ClassAccessor> 0.08
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.06
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.08
 
-L<Perl::Examples::Accessors::ClassInsideOut> 0.06
+L<Perl::Examples::Accessors::ClassInsideOut> 0.08
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.06
+L<Perl::Examples::Accessors::ClassTiny> 0.08
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.06
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.08
 
-L<Perl::Examples::Accessors::Hash> 0.06
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.08
 
-L<Perl::Examples::Accessors::Mo> 0.06
+L<Perl::Examples::Accessors::Hash> 0.08
 
-L<Perl::Examples::Accessors::MojoBase> 0.06
+L<Perl::Examples::Accessors::Mo> 0.08
 
-L<Perl::Examples::Accessors::Moo> 0.06
+L<Perl::Examples::Accessors::MojoBase> 0.08
 
-L<Perl::Examples::Accessors::Moose> 0.06
+L<Perl::Examples::Accessors::Moo> 0.08
 
-L<Perl::Examples::Accessors::Mouse> 0.06
+L<Perl::Examples::Accessors::Moose> 0.08
 
-L<Perl::Examples::Accessors::ObjectSimple> 0.06
+L<Perl::Examples::Accessors::Mouse> 0.08
 
-L<Perl::Examples::Accessors::SimpleAccessor> 0.06
+L<Perl::Examples::Accessors::ObjectSimple> 0.08
+
+L<Perl::Examples::Accessors::SimpleAccessor> 0.08
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Mo (perl_code)
+=item * Object::Simple (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
 
 
 
-=item * Class::XSAccessor (perl_code)
+=item * Moo (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::InsideOut (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o }; $o->attr1(42)
-
-
-
-=item * Simple::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
 
 
 
@@ -140,35 +126,11 @@ Code template:
 
 
 
-=item * Class::XSAccessor::Array (perl_code)
+=item * Mo (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
-
-
-
-=item * Moose (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o }; $o->attr1(42)
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
-
-
-
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Mo->new; $o }; $o->attr1(42)
 
 
 
@@ -188,11 +150,43 @@ Code template:
 
 
 
-=item * Moo (perl_code)
+=item * Moose (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::Moo->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::Moose->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::Tiny (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassTiny->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessor->new; $o }; $o->attr1(42)
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::Hash->new; $o }; $o->attr1(42)
+
+
+
+=item * Simple::Accessor (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::SimpleAccessor->new; $o }; $o->attr1(42)
 
 
 
@@ -204,11 +198,27 @@ Code template:
 
 
 
-=item * Object::Simple (perl_code)
+=item * Class::Accessor (perl_code)
 
 Code template:
 
- state $o = do { my $o = Perl::Examples::Accessors::ObjectSimple->new; $o }; $o->attr1(42)
+ state $o = do { my $o = Perl::Examples::Accessors::ClassAccessor->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassXSAccessorArray->new; $o }; $o->attr1(42)
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ state $o = do { my $o = Perl::Examples::Accessors::ClassInsideOut->new; $o }; $o->attr1(42)
 
 
 
@@ -232,29 +242,31 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Set >>):
 
+ #table1#
  +----------------------------+-----------+-----------+------------+---------+---------+
  | participant                | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +----------------------------+-----------+-----------+------------+---------+---------+
- | Simple::Accessor           |    326000 |  3.07     |     1      | 2.5e-09 |      20 |
- | Class::Accessor            |   1825000 |  0.5478   |     5.601  | 1.1e-11 |      20 |
- | Class::InsideOut           |   2840000 |  0.352    |     8.72   | 1.7e-10 |      33 |
- | no generator (hash-based)  |   4370000 |  0.229    |    13.4    |   1e-10 |      21 |
- | Moose                      |   4600000 |  0.22     |    14      | 4.2e-10 |      20 |
- | no generator (array-based) |   4623130 |  0.216304 |    14.1865 |   0     |      24 |
- | Mo                         |   4720000 |  0.212    |    14.5    |   1e-10 |      22 |
- | Mojo::Base                 |   5020000 |  0.199    |    15.4    | 9.5e-11 |      24 |
- | Class::Accessor::Array     |   5400000 |  0.19     |    16      | 4.2e-10 |      20 |
- | Object::Simple             |   5410000 |  0.185    |    16.6    |   1e-10 |      20 |
- | Mouse                      |  10400000 |  0.0958   |    32      | 7.1e-11 |      24 |
- | Class::XSAccessor          |  11000000 |  0.093    |    33      | 2.1e-10 |      20 |
- | Moo                        |  10900000 |  0.0919   |    33.4    | 4.7e-11 |      35 |
- | Class::XSAccessor::Array   |  12200000 |  0.0817   |    37.5    | 5.2e-11 |      21 |
- | raw hash access            |  20500000 |  0.0489   |    62.8    | 1.2e-11 |      21 |
- | raw array access           |  29300000 |  0.0341   |    90      | 1.2e-11 |      23 |
+ | Simple::Accessor           |    190000 |    5.2    |       1    | 2.7e-08 |      20 |
+ | Class::Accessor            |   1600000 |    0.62   |       8.3  | 1.7e-09 |      20 |
+ | Class::InsideOut           |   2007000 |    0.4982 |      10.43 | 4.6e-11 |      20 |
+ | Moose                      |   3600000 |    0.28   |      19    | 4.2e-10 |      20 |
+ | Mojo::Base                 |   3620000 |    0.276  |      18.8  | 5.8e-11 |      20 |
+ | Class::Tiny                |   3720000 |    0.269  |      19.4  | 4.6e-11 |      20 |
+ | Class::Accessor::Array     |   4000000 |    0.25   |      21    | 4.2e-10 |      20 |
+ | Mo                         |   4200000 |    0.24   |      22    | 1.2e-09 |      21 |
+ | Object::Simple             |   4380000 |    0.228  |      22.8  | 1.5e-10 |      20 |
+ | no generator (hash-based)  |   4530000 |    0.221  |      23.6  | 4.6e-11 |      20 |
+ | no generator (array-based) |   5100000 |    0.2    |      26    | 3.8e-10 |      27 |
+ | Mouse                      |   9060000 |    0.11   |      47.1  | 4.7e-11 |      22 |
+ | Class::XSAccessor          |  10200000 |    0.0984 |      52.8  | 4.5e-11 |      20 |
+ | Class::XSAccessor::Array   |  11500000 |    0.0872 |      59.6  | 6.9e-11 |      20 |
+ | Moo                        |  12000000 |    0.083  |      63    | 1.7e-10 |      22 |
+ | raw hash access            |  18200000 |    0.0548 |      94.8  | 4.6e-11 |      20 |
+ | raw array access           |  24000000 |    0.042  |     120    | 4.6e-11 |      20 |
  +----------------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
